@@ -1,3 +1,63 @@
+#' Detecting Non-numeric Values.
+#'
+#' Check whether or not an input matrix includes any non-numeric values (NA, NULL, "", character, etc) before being used for training. If any non-numeric values exist, then TrainBuddle() or FetchBuddle() will return non-numeric results.
+#'@param X an n-by-p matrix.
+#'
+#'@return A list of (n+1) values where n is the number of non-numeric values. The first element of the list is n, and all other elements are entries of X where non-numeric values occur. For example, when the (1,1)th and the (2,3)th entries of a 5-by-5 matrix X are non-numeric, then the list returned by CheckNonNumeric() will contain 2, (1,1), and (2,3).
+#'
+#'@examples
+#'
+#'n = 5;
+#'p = 5;
+#'X = matrix(0, n, p)       #### Generate a 5-by-5 matrix which includes two NA's. 
+#'X[1,1] = NA
+#'X[2,3] = NA
+#'
+#'lst = CheckNonNumeric(X)
+#'
+#'lst
+#'
+#'@export
+#'@seealso GetPrecision(), FetchBuddle(), MakeConfusionMatrix(), OneHot2Label(), Split2TrainTest(), TrainBuddle()
+
+
+CheckNonNumeric = function(X){
+  
+  dimm = dim(X)
+  n = dimm[1]
+  p = dimm[2]
+  
+  
+  nInc = 0
+  lst = list()
+  nIndex=2
+  
+  for(i in 1:n){
+    
+    for(j in 1:p){
+      
+      val = X[i, j]
+      if((is.na(val)==TRUE) || is.null(val)==TRUE || is.numeric(val)==FALSE){
+        nInc = nInc+1
+        lst[[nIndex]] = c(i,j)
+        nIndex=nIndex+1
+      }
+    }
+  }
+  
+  lst[[1]] = nInc
+  
+  return(lst)
+  
+}
+
+
+
+
+
+
+
+
 
 #' Implementing Statistical Classification and Regression.
 #'
@@ -149,7 +209,7 @@
 #'@references
 #'[3] Weilman, S. Deep Learning from Scratch. O'Reilly Media, 2019. Print.
 #'@export
-#'@seealso CheckNonNumeric(), GetPrecision(), FetchBuddle(), MakeConfusionMatrix(), OneHot2Label(), Split2TrainTest()
+#    ####  seealso CheckNonNumeric(), GetPrecision(), FetchBuddle(), MakeConfusionMatrix(), OneHot2Label(), Split2TrainTest()
 #'@importFrom Rcpp evalCpp 
 #'@useDynLib Buddle
 
@@ -428,8 +488,6 @@ TrainBuddle = function(formula.string, data, train.ratio=0.7, arrange=0, batch.s
 #'[3] Weilman, S. Deep Learning from Scratch. O'Reilly Media, 2019. Print.
 #'@export
 #'@seealso CheckNonNumeric(), GetPrecision(), MakeConfusionMatrix(), OneHot2Label(), Split2TrainTest(), TrainBuddle()
-#'@importFrom Rcpp evalCpp 
-#'@useDynLib Buddle
 
 
 
@@ -459,60 +517,6 @@ FetchBuddle = function(X, lW, lb, lParam){
 
 
 
-#' Detecting Non-numeric Values.
-#'
-#' Check whether or not an input matrix includes any non-numeric values (NA, NULL, "", character, etc) before being used for training. If any non-numeric values exist, then TrainBuddle() or FetchBuddle() will return non-numeric results.
-#'@param X an n-by-p matrix.
-#'
-#'@return A list of (n+1) values where n is the number of non-numeric values. The first element of the list is n, and all other elements are entries of X where non-numeric values occur. For example, when the (1,1)th and the (2,3)th entries of a 5-by-5 matrix X are non-numeric, then the list returned by CheckNonNumeric() will contain 2, (1,1), and (2,3).
-#'
-#'@examples
-#'
-#'n = 5;
-#'p = 5;
-#'X = matrix(0, n, p)       #### Generate a 5-by-5 matrix which includes two NA's. 
-#'X[1,1] = NA
-#'X[2,3] = NA
-#'
-#'lst = CheckNonNumeric(X)
-#'
-#'lst
-#'
-#'@export
-#'@seealso GetPrecision(), FetchBuddle(), MakeConfusionMatrix(), OneHot2Label(), Split2TrainTest(), TrainBuddle()
-#'@importFrom Rcpp evalCpp 
-#'@useDynLib Buddle
-
-
-CheckNonNumeric = function(X){
-  
-  dimm = dim(X)
-  n = dimm[1]
-  p = dimm[2]
-  
-  
-  nInc = 0
-  lst = list()
-  nIndex=2
-  
-  for(i in 1:n){
-    
-    for(j in 1:p){
-      
-      val = X[i, j]
-      if((is.na(val)==TRUE) || is.null(val)==TRUE || is.numeric(val)==FALSE){
-        nInc = nInc+1
-        lst[[nIndex]] = c(i,j)
-        nIndex=nIndex+1
-      }
-    }
-  }
-  
-  lst[[1]] = nInc
-  
-  return(lst)
-  
-}
 
 
 
@@ -565,8 +569,6 @@ CheckNonNumeric = function(X){
 #'
 #'@export
 #'@seealso CheckNonNumeric(), GetPrecision(), FetchBuddle(), MakeConfusionMatrix(), OneHot2Label(), TrainBuddle()
-#'@importFrom Rcpp evalCpp
-#'@useDynLib Buddle
 
 
 Split2TrainTest=function(Y, X, train.ratio){
@@ -685,8 +687,6 @@ Split2TrainTest=function(Y, X, train.ratio){
 #'
 #'@export
 #'@seealso CheckNonNumeric(), GetPrecision(), FetchBuddle(), MakeConfusionMatrix(), Split2TrainTest(), TrainBuddle()
-#'@importFrom Rcpp evalCpp 
-#'@useDynLib Buddle
 
 
 
@@ -743,8 +743,6 @@ OneHot2Label = function(OHE, Label){
 #'
 #'@export
 #'@seealso CheckNonNumeric(), GetPrecision(), FetchBuddle(), OneHot2Label(), Split2TrainTest(), TrainBuddle()
-#'@importFrom Rcpp evalCpp 
-#'@useDynLib Buddle
 
 
 MakeConfusionMatrix = function(predicted.label, true.label, Label){
@@ -812,8 +810,6 @@ MakeConfusionMatrix = function(predicted.label, true.label, Label){
 #'
 #'@export
 #'@seealso CheckNonNumeric(), FetchBuddle(), MakeConfusionMatrix(), OneHot2Label(), Split2TrainTest(), TrainBuddle()
-#'@importFrom Rcpp evalCpp 
-#'@useDynLib Buddle
 
 
 GetPrecision = function(confusion.matrix){
@@ -921,45 +917,6 @@ ListVar = function(Str){
 }
 
 
-SplitVariable = function(Str){
-  
-  if(class(Str)=="character"){
-    fstr = formula(Str)
-  }else{
-    fstr = Str
-  }
-  
-  Response = fstr[[2]]
-  lPredictor = fstr[[3]]
-  
-  lst = list()
-  lst[[1]] = Response
-  
-  nIter = 100000
-  
-  nInc=2
-  for(i in 1:nIter){
-    
-    len = length(lPredictor)
-    
-    if(len==1){
-      
-      lst[[nInc]] = lPredictor
-      break
-    }else{
-      lst[[nInc]] = lPredictor[[3]]
-      nInc=nInc+1
-      lPredictor = lPredictor[[2]]
-    }
-    
-    
-    
-  }
-  
-  
-  return(lst)
-  
-}
 
 
 
