@@ -1,6 +1,6 @@
 
-#ifndef __L2LOSS_H
-#define __L2LOSS_H
+#ifndef xxL2LOSS_H
+#define xxL2LOSS_H
 
 class L2loss{
 
@@ -21,11 +21,11 @@ public:
     n = 1;
   }
   
-  L2loss(int _r, int _n) // Constructor
-    : y(_r, _n), dOut(_r,_n) { // Default matrix member variable initialization
+  L2loss(int xr, int xn) // Constructor
+    : y(xr, xn), dOut(xr,xn) { // Default matrix member variable initialization
     
-    r = _r;
-    n = _n;
+    r = xr;
+    n = xn;
     loss = 0;
     
     y.zeros();
@@ -36,9 +36,9 @@ public:
   arma::mat Get_dOut();
   double Get_loss();
   
-  void forward(arma::mat X, arma::mat _t); 
+  void forward(arma::mat X, arma::mat xt); 
   void forward_predict(arma::mat X); 
-  void backward(arma::mat _t);
+  void backward(arma::mat xt);
   
 };
 
@@ -59,11 +59,11 @@ double L2loss::Get_loss(){
 }
 
 
-void L2loss::forward(arma::mat X, arma::mat _t){
+void L2loss::forward(arma::mat X, arma::mat xt){
   
   y = X;
   
-  arma::mat yt = abs(y - _t);
+  arma::mat yt = abs(y - xt);
   loss = 0.5* accu( yt%yt)/n;
   
 }
@@ -75,9 +75,9 @@ void L2loss::forward_predict(arma::mat X){
 }
 
 
-void L2loss::backward(arma::mat _t){
+void L2loss::backward(arma::mat xt){
 
-  dOut = (y - _t)/n;
+  dOut = (y - xt)/n;
   
 }
 
