@@ -1,6 +1,6 @@
 
-#ifndef __SINC_H
-#define __SINC_H
+#ifndef xxSINC_H
+#define xxSINC_H
 
 
 class Sinc{
@@ -20,19 +20,19 @@ public:
     p=0;
   }
   
-  Sinc(int _p, int _n) // Constructor
-    : Out(_p, _n), dOut(_p, _n) { // Default matrix member variable initialization
+  Sinc(int xp, int xn) // Constructor
+    : Out(xp, xn), dOut(xp, xn) { // Default matrix member variable initialization
     
-    n = _n;
-    p = _p;
+    n = xn;
+    p = xp;
     
   }
   
   arma::mat Get_Out();
   arma::mat Get_dOut();
   
-  void forward(arma::mat _X);
-  void backward(arma::mat _X, arma::mat _dOut);
+  void forward(arma::mat xX);
+  void backward(arma::mat xX, arma::mat xdOut);
   
   
 };
@@ -57,12 +57,12 @@ void Sinc::forward(arma::mat X){
 }
 
 
-void Sinc::backward(arma::mat X, arma::mat _dOut){
+void Sinc::backward(arma::mat X, arma::mat xdOut){
   
   double del = 1e-7;
   arma::uvec ind = find(X == 0);
   
-  dOut = _dOut % ( cos(X)/(X+del) - sin(X)/( X%X+del ));
+  dOut = xdOut % ( cos(X)/(X+del) - sin(X)/( X%X+del ));
   dOut.elem( ind ).zeros();
   
 
